@@ -6,7 +6,7 @@ Mandel - Async model layer for MongoDB objects using Mango
 
 =head1 VERSION
 
-0.26
+0.27
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ use Mandel::Model;
 use Mango;
 use Carp 'confess';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 ATTRIBUTES
 
@@ -285,21 +285,6 @@ sub initialize {
   }
 }
 
-=head2 import
-
-See L</SYNOPSIS>.
-
-=cut
-
-sub import {
-  my ($class) = @_;
-  my $caller = caller;
-  return unless $class eq __PACKAGE__;
-  Mojo::Util::deprecated("use Mandel; will be deprecated. Use Mojo::Base 'Mandel'; instead");
-  @_ = ($class, __PACKAGE__);
-  goto &Mojo::Base::import;
-}
-
 sub _storage_collection {
   $_[0]->storage->db->collection($_[1]);
 }
